# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
from typing import Callable, Dict, Optional, Sequence, Tuple, Union

from google.api_core import grpc_helpers  # type: ignore
from google.api_core import operations_v1  # type: ignore
from google.api_core import gapic_v1  # type: ignore
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.auth.transport.grpc import SslCredentials  # type: ignore

import grpc  # type: ignore

from google.cloud.dialogflowcx_v3.types import test_case
from google.cloud.dialogflowcx_v3.types import test_case as gcdc_test_case
from google.longrunning import operations_pb2  # type: ignore
from google.protobuf import empty_pb2  # type: ignore
from .base import TestCasesTransport, DEFAULT_CLIENT_INFO


class TestCasesGrpcTransport(TestCasesTransport):
    """gRPC backend transport for TestCases.

    Service for managing [Test
    Cases][google.cloud.dialogflow.cx.v3.TestCase] and [Test Case
    Results][google.cloud.dialogflow.cx.v3.TestCaseResult].

    This class defines the same methods as the primary client, so the
    primary client can load the underlying transport implementation
    and call it.

    It sends protocol buffers over the wire using gRPC (which is built on
    top of HTTP/2); the ``grpcio`` package must be installed.
    """

    _stubs: Dict[str, Callable]

    def __init__(
        self,
        *,
        host: str = "dialogflow.googleapis.com",
        credentials: ga_credentials.Credentials = None,
        credentials_file: str = None,
        scopes: Sequence[str] = None,
        channel: grpc.Channel = None,
        api_mtls_endpoint: str = None,
        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
        ssl_channel_credentials: grpc.ChannelCredentials = None,
        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
                This argument is ignored if ``channel`` is provided.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is ignored if ``channel`` is provided.
            scopes (Optional(Sequence[str])): A list of scopes. This argument is
                ignored if ``channel`` is provided.
            channel (Optional[grpc.Channel]): A ``Channel`` instance through
                which to make calls.
            api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                If provided, it overrides the ``host`` argument and tries to create
                a mutual TLS channel with client SSL credentials from
                ``client_cert_source`` or applicatin default SSL credentials.
            client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
                Deprecated. A callback to provide client SSL certificate bytes and
                private key bytes, both in PEM format. It is ignored if
                ``api_mtls_endpoint`` is None.
            ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
                for grpc channel. It is ignored if ``channel`` is provided.
            client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
                A callback to provide client certificate bytes and private key bytes,
                both in PEM format. It is used to configure mutual TLS channel. It is
                ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.

        Raises:
          google.auth.exceptions.MutualTLSChannelError: If mutual TLS transport
              creation failed for any reason.
          google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
              and ``credentials_file`` are passed.
        """
        self._grpc_channel = None
        self._ssl_channel_credentials = ssl_channel_credentials
        self._stubs: Dict[str, Callable] = {}
        self._operations_client = None

        if api_mtls_endpoint:
            warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
        if client_cert_source:
            warnings.warn("client_cert_source is deprecated", DeprecationWarning)

        if channel:
            # Ignore credentials if a channel was passed.
            credentials = False
            # If a channel was explicitly provided, set it.
            self._grpc_channel = channel
            self._ssl_channel_credentials = None

        else:
            if api_mtls_endpoint:
                host = api_mtls_endpoint

                # Create SSL credentials with client_cert_source or application
                # default SSL credentials.
                if client_cert_source:
                    cert, key = client_cert_source()
                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
                        certificate_chain=cert, private_key=key
                    )
                else:
                    self._ssl_channel_credentials = SslCredentials().ssl_credentials

            else:
                if client_cert_source_for_mtls and not ssl_channel_credentials:
                    cert, key = client_cert_source_for_mtls()
                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
                        certificate_chain=cert, private_key=key
                    )

        # The base transport sets the host, credentials and scopes
        super().__init__(
            host=host,
            credentials=credentials,
            credentials_file=credentials_file,
            scopes=scopes,
            quota_project_id=quota_project_id,
            client_info=client_info,
            always_use_jwt_access=always_use_jwt_access,
        )

        if not self._grpc_channel:
            self._grpc_channel = type(self).create_channel(
                self._host,
                credentials=self._credentials,
                credentials_file=credentials_file,
                scopes=self._scopes,
                ssl_credentials=self._ssl_channel_credentials,
                quota_project_id=quota_project_id,
                options=[
                    ("grpc.max_send_message_length", -1),
                    ("grpc.max_receive_message_length", -1),
                ],
            )

        # Wrap messages. This must be done after self._grpc_channel exists
        self._prep_wrapped_messages(client_info)

    @classmethod
    def create_channel(
        cls,
        host: str = "dialogflow.googleapis.com",
        credentials: ga_credentials.Credentials = None,
        credentials_file: str = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        **kwargs,
    ) -> grpc.Channel:
        """Create and return a gRPC channel object.
        Args:
            host (Optional[str]): The host for the channel to use.
            credentials (Optional[~.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
                service. These are only used when credentials are not specified and
                are passed to :func:`google.auth.default`.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            kwargs (Optional[dict]): Keyword arguments, which are passed to the
                channel creation.
        Returns:
            grpc.Channel: A gRPC channel object.

        Raises:
            google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
              and ``credentials_file`` are passed.
        """

        return grpc_helpers.create_channel(
            host,
            credentials=credentials,
            credentials_file=credentials_file,
            quota_project_id=quota_project_id,
            default_scopes=cls.AUTH_SCOPES,
            scopes=scopes,
            default_host=cls.DEFAULT_HOST,
            **kwargs,
        )

    @property
    def grpc_channel(self) -> grpc.Channel:
        """Return the channel designed to connect to this service.
        """
        return self._grpc_channel

    @property
    def operations_client(self) -> operations_v1.OperationsClient:
        """Create the client designed to process long-running operations.

        This property caches on the instance; repeated calls return the same
        client.
        """
        # Sanity check: Only create a new client if we do not already have one.
        if self._operations_client is None:
            self._operations_client = operations_v1.OperationsClient(self.grpc_channel)

        # Return the client from cache.
        return self._operations_client

    @property
    def list_test_cases(
        self,
    ) -> Callable[[test_case.ListTestCasesRequest], test_case.ListTestCasesResponse]:
        r"""Return a callable for the list test cases method over gRPC.

        Fetches a list of test cases for a given agent.

        Returns:
            Callable[[~.ListTestCasesRequest],
                    ~.ListTestCasesResponse]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_test_cases" not in self._stubs:
            self._stubs["list_test_cases"] = self.grpc_channel.unary_unary(
                "/google.cloud.dialogflow.cx.v3.TestCases/ListTestCases",
                request_serializer=test_case.ListTestCasesRequest.serialize,
                response_deserializer=test_case.ListTestCasesResponse.deserialize,
            )
        return self._stubs["list_test_cases"]

    @property
    def batch_delete_test_cases(
        self,
    ) -> Callable[[test_case.BatchDeleteTestCasesRequest], empty_pb2.Empty]:
        r"""Return a callable for the batch delete test cases method over gRPC.

        Batch deletes test cases.

        Returns:
            Callable[[~.BatchDeleteTestCasesRequest],
                    ~.Empty]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "batch_delete_test_cases" not in self._stubs:
            self._stubs["batch_delete_test_cases"] = self.grpc_channel.unary_unary(
                "/google.cloud.dialogflow.cx.v3.TestCases/BatchDeleteTestCases",
                request_serializer=test_case.BatchDeleteTestCasesRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["batch_delete_test_cases"]

    @property
    def get_test_case(
        self,
    ) -> Callable[[test_case.GetTestCaseRequest], test_case.TestCase]:
        r"""Return a callable for the get test case method over gRPC.

        Gets a test case.

        Returns:
            Callable[[~.GetTestCaseRequest],
                    ~.TestCase]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_test_case" not in self._stubs:
            self._stubs["get_test_case"] = self.grpc_channel.unary_unary(
                "/google.cloud.dialogflow.cx.v3.TestCases/GetTestCase",
                request_serializer=test_case.GetTestCaseRequest.serialize,
                response_deserializer=test_case.TestCase.deserialize,
            )
        return self._stubs["get_test_case"]

    @property
    def create_test_case(
        self,
    ) -> Callable[[gcdc_test_case.CreateTestCaseRequest], gcdc_test_case.TestCase]:
        r"""Return a callable for the create test case method over gRPC.

        Creates a test case for the given agent.

        Returns:
            Callable[[~.CreateTestCaseRequest],
                    ~.TestCase]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_test_case" not in self._stubs:
            self._stubs["create_test_case"] = self.grpc_channel.unary_unary(
                "/google.cloud.dialogflow.cx.v3.TestCases/CreateTestCase",
                request_serializer=gcdc_test_case.CreateTestCaseRequest.serialize,
                response_deserializer=gcdc_test_case.TestCase.deserialize,
            )
        return self._stubs["create_test_case"]

    @property
    def update_test_case(
        self,
    ) -> Callable[[gcdc_test_case.UpdateTestCaseRequest], gcdc_test_case.TestCase]:
        r"""Return a callable for the update test case method over gRPC.

        Updates the specified test case.

        Returns:
            Callable[[~.UpdateTestCaseRequest],
                    ~.TestCase]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_test_case" not in self._stubs:
            self._stubs["update_test_case"] = self.grpc_channel.unary_unary(
                "/google.cloud.dialogflow.cx.v3.TestCases/UpdateTestCase",
                request_serializer=gcdc_test_case.UpdateTestCaseRequest.serialize,
                response_deserializer=gcdc_test_case.TestCase.deserialize,
            )
        return self._stubs["update_test_case"]

    @property
    def run_test_case(
        self,
    ) -> Callable[[test_case.RunTestCaseRequest], operations_pb2.Operation]:
        r"""Return a callable for the run test case method over gRPC.

        Kicks off a test case run.

        Returns:
            Callable[[~.RunTestCaseRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "run_test_case" not in self._stubs:
            self._stubs["run_test_case"] = self.grpc_channel.unary_unary(
                "/google.cloud.dialogflow.cx.v3.TestCases/RunTestCase",
                request_serializer=test_case.RunTestCaseRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["run_test_case"]

    @property
    def batch_run_test_cases(
        self,
    ) -> Callable[[test_case.BatchRunTestCasesRequest], operations_pb2.Operation]:
        r"""Return a callable for the batch run test cases method over gRPC.

        Kicks off a batch run of test cases.

        Returns:
            Callable[[~.BatchRunTestCasesRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "batch_run_test_cases" not in self._stubs:
            self._stubs["batch_run_test_cases"] = self.grpc_channel.unary_unary(
                "/google.cloud.dialogflow.cx.v3.TestCases/BatchRunTestCases",
                request_serializer=test_case.BatchRunTestCasesRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["batch_run_test_cases"]

    @property
    def calculate_coverage(
        self,
    ) -> Callable[
        [test_case.CalculateCoverageRequest], test_case.CalculateCoverageResponse
    ]:
        r"""Return a callable for the calculate coverage method over gRPC.

        Calculates the test coverage for an agent.

        Returns:
            Callable[[~.CalculateCoverageRequest],
                    ~.CalculateCoverageResponse]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "calculate_coverage" not in self._stubs:
            self._stubs["calculate_coverage"] = self.grpc_channel.unary_unary(
                "/google.cloud.dialogflow.cx.v3.TestCases/CalculateCoverage",
                request_serializer=test_case.CalculateCoverageRequest.serialize,
                response_deserializer=test_case.CalculateCoverageResponse.deserialize,
            )
        return self._stubs["calculate_coverage"]

    @property
    def import_test_cases(
        self,
    ) -> Callable[[test_case.ImportTestCasesRequest], operations_pb2.Operation]:
        r"""Return a callable for the import test cases method over gRPC.

        Imports the test cases from a Cloud Storage bucket or
        a local file. It always creates new test cases and won't
        overwite any existing ones. The provided ID in the
        imported test case is neglected.

        Returns:
            Callable[[~.ImportTestCasesRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "import_test_cases" not in self._stubs:
            self._stubs["import_test_cases"] = self.grpc_channel.unary_unary(
                "/google.cloud.dialogflow.cx.v3.TestCases/ImportTestCases",
                request_serializer=test_case.ImportTestCasesRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["import_test_cases"]

    @property
    def export_test_cases(
        self,
    ) -> Callable[[test_case.ExportTestCasesRequest], operations_pb2.Operation]:
        r"""Return a callable for the export test cases method over gRPC.

        Exports the test cases under the agent to a Cloud
        Storage bucket or a local file. Filter can be applied to
        export a subset of test cases.

        Returns:
            Callable[[~.ExportTestCasesRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "export_test_cases" not in self._stubs:
            self._stubs["export_test_cases"] = self.grpc_channel.unary_unary(
                "/google.cloud.dialogflow.cx.v3.TestCases/ExportTestCases",
                request_serializer=test_case.ExportTestCasesRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["export_test_cases"]

    @property
    def list_test_case_results(
        self,
    ) -> Callable[
        [test_case.ListTestCaseResultsRequest], test_case.ListTestCaseResultsResponse
    ]:
        r"""Return a callable for the list test case results method over gRPC.

        Fetches a list of results for a given test case.

        Returns:
            Callable[[~.ListTestCaseResultsRequest],
                    ~.ListTestCaseResultsResponse]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_test_case_results" not in self._stubs:
            self._stubs["list_test_case_results"] = self.grpc_channel.unary_unary(
                "/google.cloud.dialogflow.cx.v3.TestCases/ListTestCaseResults",
                request_serializer=test_case.ListTestCaseResultsRequest.serialize,
                response_deserializer=test_case.ListTestCaseResultsResponse.deserialize,
            )
        return self._stubs["list_test_case_results"]

    @property
    def get_test_case_result(
        self,
    ) -> Callable[[test_case.GetTestCaseResultRequest], test_case.TestCaseResult]:
        r"""Return a callable for the get test case result method over gRPC.

        Gets a test case result.

        Returns:
            Callable[[~.GetTestCaseResultRequest],
                    ~.TestCaseResult]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_test_case_result" not in self._stubs:
            self._stubs["get_test_case_result"] = self.grpc_channel.unary_unary(
                "/google.cloud.dialogflow.cx.v3.TestCases/GetTestCaseResult",
                request_serializer=test_case.GetTestCaseResultRequest.serialize,
                response_deserializer=test_case.TestCaseResult.deserialize,
            )
        return self._stubs["get_test_case_result"]


__all__ = ("TestCasesGrpcTransport",)



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.protobuf import struct_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.dialogflow.cx.v3", manifest={"ResponseMessage",},
)


class ResponseMessage(proto.Message):
    r"""Represents a response message that can be returned by a
    conversational agent.

    Response messages are also used for output audio synthesis. The
    approach is as follows:

    -  If at least one OutputAudioText response is present, then all
       OutputAudioText responses are linearly concatenated, and the
       result is used for output audio synthesis.
    -  If the OutputAudioText responses are a mixture of text and SSML,
       then the concatenated result is treated as SSML; otherwise, the
       result is treated as either text or SSML as appropriate. The
       agent designer should ideally use either text or SSML
       consistently throughout the bot design.
    -  Otherwise, all Text responses are linearly concatenated, and the
       result is used for output audio synthesis.

    This approach allows for more sophisticated user experience
    scenarios, where the text displayed to the user may differ from what
    is heard.

    Attributes:
        text (google.cloud.dialogflowcx_v3.types.ResponseMessage.Text):
            Returns a text response.
        payload (google.protobuf.struct_pb2.Struct):
            Returns a response containing a custom,
            platform-specific payload.
        conversation_success (google.cloud.dialogflowcx_v3.types.ResponseMessage.ConversationSuccess):
            Indicates that the conversation succeeded.
        output_audio_text (google.cloud.dialogflowcx_v3.types.ResponseMessage.OutputAudioText):
            A text or ssml response that is
            preferentially used for TTS output audio
            synthesis, as described in the comment on the
            ResponseMessage message.
        live_agent_handoff (google.cloud.dialogflowcx_v3.types.ResponseMessage.LiveAgentHandoff):
            Hands off conversation to a human agent.
        end_interaction (google.cloud.dialogflowcx_v3.types.ResponseMessage.EndInteraction):
            Output only. A signal that indicates the interaction with
            the Dialogflow agent has ended. This message is generated by
            Dialogflow only when the conversation reaches
            ``END_SESSION`` page. It is not supposed to be defined by
            the user.

            It's guaranteed that there is at most one such message in
            each response.
        play_audio (google.cloud.dialogflowcx_v3.types.ResponseMessage.PlayAudio):
            Signal that the client should play an audio clip hosted at a
            client-specific URI. Dialogflow uses this to construct
            [mixed_audio][google.cloud.dialogflow.cx.v3.ResponseMessage.mixed_audio].
            However, Dialogflow itself does not try to read or process
            the URI in any way.
        mixed_audio (google.cloud.dialogflowcx_v3.types.ResponseMessage.MixedAudio):
            Output only. An audio response message composed of both the
            synthesized Dialogflow agent responses and responses defined
            via
            [play_audio][google.cloud.dialogflow.cx.v3.ResponseMessage.play_audio].
            This message is generated by Dialogflow only and not
            supposed to be defined by the user.
    """

    class Text(proto.Message):
        r"""The text response message.
        Attributes:
            text (Sequence[str]):
                Required. A collection of text responses.
            allow_playback_interruption (bool):
                Output only. Whether the playback of this
                message can be interrupted by the end user's
                speech and the client can then starts the next
                Dialogflow request.
        """

        text = proto.RepeatedField(proto.STRING, number=1,)
        allow_playback_interruption = proto.Field(proto.BOOL, number=2,)

    class LiveAgentHandoff(proto.Message):
        r"""Indicates that the conversation should be handed off to a live
        agent.

        Dialogflow only uses this to determine which conversations were
        handed off to a human agent for measurement purposes. What else to
        do with this signal is up to you and your handoff procedures.

        You may set this, for example:

        -  In the
           [entry_fulfillment][google.cloud.dialogflow.cx.v3.Page.entry_fulfillment]
           of a [Page][google.cloud.dialogflow.cx.v3.Page] if entering the
           page indicates something went extremely wrong in the
           conversation.
        -  In a webhook response when you determine that the customer issue
           can only be handled by a human.

        Attributes:
            metadata (google.protobuf.struct_pb2.Struct):
                Custom metadata for your handoff procedure.
                Dialogflow doesn't impose any structure on this.
        """

        metadata = proto.Field(proto.MESSAGE, number=1, message=struct_pb2.Struct,)

    class ConversationSuccess(proto.Message):
        r"""Indicates that the conversation succeeded, i.e., the bot handled the
        issue that the customer talked to it about.

        Dialogflow only uses this to determine which conversations should be
        counted as successful and doesn't process the metadata in this
        message in any way. Note that Dialogflow also considers
        conversations that get to the conversation end page as successful
        even if they don't return
        [ConversationSuccess][google.cloud.dialogflow.cx.v3.ResponseMessage.ConversationSuccess].

        You may set this, for example:

        -  In the
           [entry_fulfillment][google.cloud.dialogflow.cx.v3.Page.entry_fulfillment]
           of a [Page][google.cloud.dialogflow.cx.v3.Page] if entering the
           page indicates that the conversation succeeded.
        -  In a webhook response when you determine that you handled the
           customer issue.

        Attributes:
            metadata (google.protobuf.struct_pb2.Struct):
                Custom metadata. Dialogflow doesn't impose
                any structure on this.
        """

        metadata = proto.Field(proto.MESSAGE, number=1, message=struct_pb2.Struct,)

    class OutputAudioText(proto.Message):
        r"""A text or ssml response that is preferentially used for TTS
        output audio synthesis, as described in the comment on the
        ResponseMessage message.

        Attributes:
            text (str):
                The raw text to be synthesized.
            ssml (str):
                The SSML text to be synthesized. For more information, see
                `SSML </speech/text-to-speech/docs/ssml>`__.
            allow_playback_interruption (bool):
                Output only. Whether the playback of this
                message can be interrupted by the end user's
                speech and the client can then starts the next
                Dialogflow request.
        """

        text = proto.Field(proto.STRING, number=1, oneof="source",)
        ssml = proto.Field(proto.STRING, number=2, oneof="source",)
        allow_playback_interruption = proto.Field(proto.BOOL, number=3,)

    class EndInteraction(proto.Message):
        r"""Indicates that interaction with the Dialogflow agent has
        ended. This message is generated by Dialogflow only and not
        supposed to be defined by the user.
            """

    class PlayAudio(proto.Message):
        r"""Specifies an audio clip to be played by the client as part of
        the response.

        Attributes:
            audio_uri (str):
                Required. URI of the audio clip. Dialogflow
                does not impose any validation on this value. It
                is specific to the client that reads it.
            allow_playback_interruption (bool):
                Output only. Whether the playback of this
                message can be interrupted by the end user's
                speech and the client can then starts the next
                Dialogflow request.
        """

        audio_uri = proto.Field(proto.STRING, number=1,)
        allow_playback_interruption = proto.Field(proto.BOOL, number=2,)

    class MixedAudio(proto.Message):
        r"""Represents an audio message that is composed of both segments
        synthesized from the Dialogflow agent prompts and ones hosted
        externally at the specified URIs. The external URIs are specified
        via
        [play_audio][google.cloud.dialogflow.cx.v3.ResponseMessage.play_audio].
        This message is generated by Dialogflow only and not supposed to be
        defined by the user.

        Attributes:
            segments (Sequence[google.cloud.dialogflowcx_v3.types.ResponseMessage.MixedAudio.Segment]):
                Segments this audio response is composed of.
        """

        class Segment(proto.Message):
            r"""Represents one segment of audio.
            Attributes:
                audio (bytes):
                    Raw audio synthesized from the Dialogflow
                    agent's response using the output config
                    specified in the request.
                uri (str):
                    Client-specific URI that points to an audio
                    clip accessible to the client. Dialogflow does
                    not impose any validation on it.
                allow_playback_interruption (bool):
                    Output only. Whether the playback of this
                    segment can be interrupted by the end user's
                    speech and the client should then start the next
                    Dialogflow request.
            """

            audio = proto.Field(proto.BYTES, number=1, oneof="content",)
            uri = proto.Field(proto.STRING, number=2, oneof="content",)
            allow_playback_interruption = proto.Field(proto.BOOL, number=3,)

        segments = proto.RepeatedField(
            proto.MESSAGE, number=1, message="ResponseMessage.MixedAudio.Segment",
        )

    text = proto.Field(proto.MESSAGE, number=1, oneof="message", message=Text,)
    payload = proto.Field(
        proto.MESSAGE, number=2, oneof="message", message=struct_pb2.Struct,
    )
    conversation_success = proto.Field(
        proto.MESSAGE, number=9, oneof="message", message=ConversationSuccess,
    )
    output_audio_text = proto.Field(
        proto.MESSAGE, number=8, oneof="message", message=OutputAudioText,
    )
    live_agent_handoff = proto.Field(
        proto.MESSAGE, number=10, oneof="message", message=LiveAgentHandoff,
    )
    end_interaction = proto.Field(
        proto.MESSAGE, number=11, oneof="message", message=EndInteraction,
    )
    play_audio = proto.Field(
        proto.MESSAGE, number=12, oneof="message", message=PlayAudio,
    )
    mixed_audio = proto.Field(
        proto.MESSAGE, number=13, oneof="message", message=MixedAudio,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from collections import OrderedDict
import functools
import re
from typing import (
    Dict,
    AsyncIterable,
    Awaitable,
    AsyncIterator,
    Sequence,
    Tuple,
    Type,
    Union,
)
import pkg_resources

import google.api_core.client_options as ClientOptions  # type: ignore
from google.api_core import exceptions as core_exceptions  # type: ignore
from google.api_core import gapic_v1  # type: ignore
from google.api_core import retry as retries  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.dialogflowcx_v3beta1.types import audio_config
from google.cloud.dialogflowcx_v3beta1.types import page
from google.cloud.dialogflowcx_v3beta1.types import session
from .transports.base import SessionsTransport, DEFAULT_CLIENT_INFO
from .transports.grpc_asyncio import SessionsGrpcAsyncIOTransport
from .client import SessionsClient


class SessionsAsyncClient:
    """A session represents an interaction with a user. You retrieve user
    input and pass it to the
    [DetectIntent][google.cloud.dialogflow.cx.v3beta1.Sessions.DetectIntent]
    method to determine user intent and respond.
    """

    _client: SessionsClient

    DEFAULT_ENDPOINT = SessionsClient.DEFAULT_ENDPOINT
    DEFAULT_MTLS_ENDPOINT = SessionsClient.DEFAULT_MTLS_ENDPOINT

    entity_type_path = staticmethod(SessionsClient.entity_type_path)
    parse_entity_type_path = staticmethod(SessionsClient.parse_entity_type_path)
    flow_path = staticmethod(SessionsClient.flow_path)
    parse_flow_path = staticmethod(SessionsClient.parse_flow_path)
    intent_path = staticmethod(SessionsClient.intent_path)
    parse_intent_path = staticmethod(SessionsClient.parse_intent_path)
    page_path = staticmethod(SessionsClient.page_path)
    parse_page_path = staticmethod(SessionsClient.parse_page_path)
    session_path = staticmethod(SessionsClient.session_path)
    parse_session_path = staticmethod(SessionsClient.parse_session_path)
    session_entity_type_path = staticmethod(SessionsClient.session_entity_type_path)
    parse_session_entity_type_path = staticmethod(
        SessionsClient.parse_session_entity_type_path
    )
    transition_route_group_path = staticmethod(
        SessionsClient.transition_route_group_path
    )
    parse_transition_route_group_path = staticmethod(
        SessionsClient.parse_transition_route_group_path
    )
    webhook_path = staticmethod(SessionsClient.webhook_path)
    parse_webhook_path = staticmethod(SessionsClient.parse_webhook_path)
    common_billing_account_path = staticmethod(
        SessionsClient.common_billing_account_path
    )
    parse_common_billing_account_path = staticmethod(
        SessionsClient.parse_common_billing_account_path
    )
    common_folder_path = staticmethod(SessionsClient.common_folder_path)
    parse_common_folder_path = staticmethod(SessionsClient.parse_common_folder_path)
    common_organization_path = staticmethod(SessionsClient.common_organization_path)
    parse_common_organization_path = staticmethod(
        SessionsClient.parse_common_organization_path
    )
    common_project_path = staticmethod(SessionsClient.common_project_path)
    parse_common_project_path = staticmethod(SessionsClient.parse_common_project_path)
    common_location_path = staticmethod(SessionsClient.common_location_path)
    parse_common_location_path = staticmethod(SessionsClient.parse_common_location_path)

    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            info.

        Args:
            info (dict): The service account private key info.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            SessionsAsyncClient: The constructed client.
        """
        return SessionsClient.from_service_account_info.__func__(SessionsAsyncClient, info, *args, **kwargs)  # type: ignore

    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            SessionsAsyncClient: The constructed client.
        """
        return SessionsClient.from_service_account_file.__func__(SessionsAsyncClient, filename, *args, **kwargs)  # type: ignore

    from_service_account_json = from_service_account_file

    @property
    def transport(self) -> SessionsTransport:
        """Returns the transport used by the client instance.

        Returns:
            SessionsTransport: The transport used by the client instance.
        """
        return self._client.transport

    get_transport_class = functools.partial(
        type(SessionsClient).get_transport_class, type(SessionsClient)
    )

    def __init__(
        self,
        *,
        credentials: ga_credentials.Credentials = None,
        transport: Union[str, SessionsTransport] = "grpc_asyncio",
        client_options: ClientOptions = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
    ) -> None:
        """Instantiates the sessions client.

        Args:
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            transport (Union[str, ~.SessionsTransport]): The
                transport to use. If set to None, a transport is chosen
                automatically.
            client_options (ClientOptions): Custom options for the client. It
                won't take effect if a ``transport`` instance is provided.
                (1) The ``api_endpoint`` property can be used to override the
                default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
                environment variable can also be used to override the endpoint:
                "always" (always use the default mTLS endpoint), "never" (always
                use the default regular endpoint) and "auto" (auto switch to the
                default mTLS endpoint if client certificate is present, this is
                the default value). However, the ``api_endpoint`` property takes
                precedence if provided.
                (2) If GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
                is "true", then the ``client_cert_source`` property can be used
                to provide client certificate for mutual TLS transport. If
                not provided, the default SSL client certificate will be used if
                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
                set, no client certificate will be used.

        Raises:
            google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                creation failed for any reason.
        """
        self._client = SessionsClient(
            credentials=credentials,
            transport=transport,
            client_options=client_options,
            client_info=client_info,
        )

    async def detect_intent(
        self,
        request: session.DetectIntentRequest = None,
        *,
        retry: retries.Retry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> session.DetectIntentResponse:
        r"""Processes a natural language query and returns structured,
        actionable data as a result. This method is not idempotent,
        because it may cause session entity types to be updated, which
        in turn might affect results of future queries.

        Note: Always use agent versions for production traffic. See
        `Versions and
        environments <https://cloud.google.com/dialogflow/cx/docs/concept/version>`__.

        Args:
            request (:class:`google.cloud.dialogflowcx_v3beta1.types.DetectIntentRequest`):
                The request object. The request to detect user's intent.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.dialogflowcx_v3beta1.types.DetectIntentResponse:
                The message returned from the
                DetectIntent method.

        """
        # Create or coerce a protobuf request object.
        request = session.DetectIntentRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.detect_intent,
            default_retry=retries.Retry(
                initial=0.1,
                maximum=60.0,
                multiplier=1.3,
                predicate=retries.if_exception_type(
                    core_exceptions.ServiceUnavailable,
                ),
                deadline=220.0,
            ),
            default_timeout=220.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("session", request.session),)),
        )

        # Send the request.
        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)

        # Done; return the response.
        return response

    def streaming_detect_intent(
        self,
        requests: AsyncIterator[session.StreamingDetectIntentRequest] = None,
        *,
        retry: retries.Retry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> Awaitable[AsyncIterable[session.StreamingDetectIntentResponse]]:
        r"""Processes a natural language query in audio format in a
        streaming fashion and returns structured, actionable data as a
        result. This method is only available via the gRPC API (not
        REST).

        Note: Always use agent versions for production traffic. See
        `Versions and
        environments <https://cloud.google.com/dialogflow/cx/docs/concept/version>`__.

        Args:
            requests (AsyncIterator[`google.cloud.dialogflowcx_v3beta1.types.StreamingDetectIntentRequest`]):
                The request object AsyncIterator. The top-level message sent by the
                client to the
                [Sessions.StreamingDetectIntent][google.cloud.dialogflow.cx.v3beta1.Sessions.StreamingDetectIntent]
                method.
                Multiple request messages should be sent in order:

                1.  The first message must contain
                [session][google.cloud.dialogflow.cx.v3beta1.StreamingDetectIntentRequest.session],
                [query_input][google.cloud.dialogflow.cx.v3beta1.StreamingDetectIntentRequest.query_input]
                plus optionally
                [query_params][google.cloud.dialogflow.cx.v3beta1.StreamingDetectIntentRequest.query_params].
                If the client     wants to receive an audio response, it
                should also contain
                [output_audio_config][google.cloud.dialogflow.cx.v3beta1.StreamingDetectIntentRequest.output_audio_config].
                2.  If
                [query_input][google.cloud.dialogflow.cx.v3beta1.StreamingDetectIntentRequest.query_input]
                was set to
                [query_input.audio.config][google.cloud.dialogflow.cx.v3beta1.AudioInput.config],
                all subsequent messages     must contain
                [query_input.audio.audio][google.cloud.dialogflow.cx.v3beta1.AudioInput.audio]
                to continue with     Speech recognition.
                    If you decide to rather detect an intent from text
                input after you already started Speech recognition,
                please send a message     with
                [query_input.text][google.cloud.dialogflow.cx.v3beta1.QueryInput.text].
                    However, note that:

                    * Dialogflow will bill you for the audio duration so
                far.     * Dialogflow discards all Speech recognition
                results in favor of the       input text.
                    * Dialogflow will use the language code from the
                first message.
                After you sent all input, you must half-close or abort
                the request stream.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            AsyncIterable[google.cloud.dialogflowcx_v3beta1.types.StreamingDetectIntentResponse]:
                The top-level message returned from the
                StreamingDetectIntent method.

                   Multiple response messages can be returned in order:

                   1. If the input was set to streaming audio, the first
                      one or more messages contain recognition_result.
                      Each recognition_result represents a more complete
                      transcript of what the user said. The last
                      recognition_result has is_final set to true.
                   2. If enable_partial_response is true, the following
                      N messages (currently 1 <= N <= 4) contain
                      detect_intent_response. The first (N-1)
                      detect_intent_responses will have response_type
                      set to PARTIAL. The last detect_intent_response
                      has response_type set to FINAL. If response_type
                      is false, response stream only contains the final
                      detect_intent_response.

        """

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.streaming_detect_intent,
            default_timeout=220.0,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Send the request.
        response = rpc(requests, retry=retry, timeout=timeout, metadata=metadata,)

        # Done; return the response.
        return response

    async def match_intent(
        self,
        request: session.MatchIntentRequest = None,
        *,
        retry: retries.Retry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> session.MatchIntentResponse:
        r"""Returns preliminary intent match results, doesn't
        change the session status.

        Args:
            request (:class:`google.cloud.dialogflowcx_v3beta1.types.MatchIntentRequest`):
                The request object. Request of [MatchIntent][].
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.dialogflowcx_v3beta1.types.MatchIntentResponse:
                Response of [MatchIntent][].
        """
        # Create or coerce a protobuf request object.
        request = session.MatchIntentRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.match_intent,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("session", request.session),)),
        )

        # Send the request.
        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)

        # Done; return the response.
        return response

    async def fulfill_intent(
        self,
        request: session.FulfillIntentRequest = None,
        *,
        retry: retries.Retry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> session.FulfillIntentResponse:
        r"""Fulfills a matched intent returned by
        [MatchIntent][google.cloud.dialogflow.cx.v3beta1.Sessions.MatchIntent].
        Must be called after
        [MatchIntent][google.cloud.dialogflow.cx.v3beta1.Sessions.MatchIntent],
        with input from
        [MatchIntentResponse][google.cloud.dialogflow.cx.v3beta1.MatchIntentResponse].
        Otherwise, the behavior is undefined.

        Args:
            request (:class:`google.cloud.dialogflowcx_v3beta1.types.FulfillIntentRequest`):
                The request object. Request of [FulfillIntent][]
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.dialogflowcx_v3beta1.types.FulfillIntentResponse:
                Response of [FulfillIntent][]
        """
        # Create or coerce a protobuf request object.
        request = session.FulfillIntentRequest(request)

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.fulfill_intent,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata(
                (
                    (
                        "match_intent_request.session",
                        request.match_intent_request.session,
                    ),
                )
            ),
        )

        # Send the request.
        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)

        # Done; return the response.
        return response


try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-dialogflowcx",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


__all__ = ("SessionsAsyncClient",)



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.dialogflow.cx.v3beta1",
    manifest={"ValidationMessage", "ResourceName",},
)


class ValidationMessage(proto.Message):
    r"""Agent/flow validation message.
    Attributes:
        resource_type (google.cloud.dialogflowcx_v3beta1.types.ValidationMessage.ResourceType):
            The type of the resources where the message
            is found.
        resources (Sequence[str]):
            The names of the resources where the message
            is found.
        resource_names (Sequence[google.cloud.dialogflowcx_v3beta1.types.ResourceName]):
            The resource names of the resources where the
            message is found.
        severity (google.cloud.dialogflowcx_v3beta1.types.ValidationMessage.Severity):
            Indicates the severity of the message.
        detail (str):
            The message detail.
    """

    class ResourceType(proto.Enum):
        r"""Resource types."""
        RESOURCE_TYPE_UNSPECIFIED = 0
        AGENT = 1
        INTENT = 2
        INTENT_TRAINING_PHRASE = 8
        INTENT_PARAMETER = 9
        INTENTS = 10
        INTENT_TRAINING_PHRASES = 11
        ENTITY_TYPE = 3
        ENTITY_TYPES = 12
        WEBHOOK = 4
        FLOW = 5
        PAGE = 6
        PAGES = 13
        TRANSITION_ROUTE_GROUP = 7

    class Severity(proto.Enum):
        r"""Severity level."""
        SEVERITY_UNSPECIFIED = 0
        INFO = 1
        WARNING = 2
        ERROR = 3

    resource_type = proto.Field(proto.ENUM, number=1, enum=ResourceType,)
    resources = proto.RepeatedField(proto.STRING, number=2,)
    resource_names = proto.RepeatedField(
        proto.MESSAGE, number=6, message="ResourceName",
    )
    severity = proto.Field(proto.ENUM, number=3, enum=Severity,)
    detail = proto.Field(proto.STRING, number=4,)


class ResourceName(proto.Message):
    r"""Resource name and display name.
    Attributes:
        name (str):
            Name.
        display_name (str):
            Display name.
    """

    name = proto.Field(proto.STRING, number=1,)
    display_name = proto.Field(proto.STRING, number=2,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.cloud.dialogflowcx_v3beta1.types import fulfillment
from google.protobuf import field_mask_pb2  # type: ignore
from google.protobuf import struct_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.dialogflow.cx.v3beta1",
    manifest={
        "Page",
        "Form",
        "EventHandler",
        "TransitionRoute",
        "ListPagesRequest",
        "ListPagesResponse",
        "GetPageRequest",
        "CreatePageRequest",
        "UpdatePageRequest",
        "DeletePageRequest",
    },
)


class Page(proto.Message):
    r"""A Dialogflow CX conversation (session) can be described and
    visualized as a state machine. The states of a CX session are
    represented by pages.

    For each flow, you define many pages, where your combined pages can
    handle a complete conversation on the topics the flow is designed
    for. At any given moment, exactly one page is the current page, the
    current page is considered active, and the flow associated with that
    page is considered active. Every flow has a special start page. When
    a flow initially becomes active, the start page page becomes the
    current page. For each conversational turn, the current page will
    either stay the same or transition to another page.

    You configure each page to collect information from the end-user
    that is relevant for the conversational state represented by the
    page.

    For more information, see the `Page
    guide <https://cloud.google.com/dialogflow/cx/docs/concept/page>`__.

    Attributes:
        name (str):
            The unique identifier of the page. Required for the
            [Pages.UpdatePage][google.cloud.dialogflow.cx.v3beta1.Pages.UpdatePage]
            method.
            [Pages.CreatePage][google.cloud.dialogflow.cx.v3beta1.Pages.CreatePage]
            populates the name automatically. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/flows/<Flow ID>/pages/<Page ID>``.
        display_name (str):
            Required. The human-readable name of the
            page, unique within the agent.
        entry_fulfillment (google.cloud.dialogflowcx_v3beta1.types.Fulfillment):
            The fulfillment to call when the session is
            entering the page.
        form (google.cloud.dialogflowcx_v3beta1.types.Form):
            The form associated with the page, used for
            collecting parameters relevant to the page.
        transition_route_groups (Sequence[str]):
            Ordered list of
            [``TransitionRouteGroups``][google.cloud.dialogflow.cx.v3beta1.TransitionRouteGroup]
            associated with the page. Transition route groups must be
            unique within a page.

            -  If multiple transition routes within a page scope refer
               to the same intent, then the precedence order is: page's
               transition route -> page's transition route group ->
               flow's transition routes.

            -  If multiple transition route groups within a page contain
               the same intent, then the first group in the ordered list
               takes precedence.

            Format:\ ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/flows/<Flow ID>/transitionRouteGroups/<TransitionRouteGroup ID>``.
        transition_routes (Sequence[google.cloud.dialogflowcx_v3beta1.types.TransitionRoute]):
            A list of transitions for the transition rules of this page.
            They route the conversation to another page in the same
            flow, or another flow.

            When we are in a certain page, the TransitionRoutes are
            evalauted in the following order:

            -  TransitionRoutes defined in the page with intent
               specified.
            -  TransitionRoutes defined in the [transition route
               groups][google.cloud.dialogflow.cx.v3beta1.Page.transition_route_groups]
               with intent specified.
            -  TransitionRoutes defined in flow with intent specified.
            -  TransitionRoutes defined in the [transition route
               groups][google.cloud.dialogflow.cx.v3beta1.Flow.transition_route_groups]
               with intent specified.
            -  TransitionRoutes defined in the page with only condition
               specified.
            -  TransitionRoutes defined in the [transition route
               groups][google.cloud.dialogflow.cx.v3beta1.Page.transition_route_groups]
               with only condition specified.
        event_handlers (Sequence[google.cloud.dialogflowcx_v3beta1.types.EventHandler]):
            Handlers associated with the page to handle
            events such as webhook errors, no match or no
            input.
    """

    name = proto.Field(proto.STRING, number=1,)
    display_name = proto.Field(proto.STRING, number=2,)
    entry_fulfillment = proto.Field(
        proto.MESSAGE, number=7, message=fulfillment.Fulfillment,
    )
    form = proto.Field(proto.MESSAGE, number=4, message="Form",)
    transition_route_groups = proto.RepeatedField(proto.STRING, number=11,)
    transition_routes = proto.RepeatedField(
        proto.MESSAGE, number=9, message="TransitionRoute",
    )
    event_handlers = proto.RepeatedField(
        proto.MESSAGE, number=10, message="EventHandler",
    )


class Form(proto.Message):
    r"""A form is a data model that groups related parameters that can be
    collected from the user. The process in which the agent prompts the
    user and collects parameter values from the user is called form
    filling. A form can be added to a
    [page][google.cloud.dialogflow.cx.v3beta1.Page]. When form filling
    is done, the filled parameters will be written to the
    [session][google.cloud.dialogflow.cx.v3beta1.SessionInfo.parameters].

    Attributes:
        parameters (Sequence[google.cloud.dialogflowcx_v3beta1.types.Form.Parameter]):
            Parameters to collect from the user.
    """

    class Parameter(proto.Message):
        r"""Represents a form parameter.
        Attributes:
            display_name (str):
                Required. The human-readable name of the
                parameter, unique within the form.
            required (bool):
                Indicates whether the parameter is required.
                Optional parameters will not trigger prompts;
                however, they are filled if the user specifies
                them. Required parameters must be filled before
                form filling concludes.
            entity_type (str):
                Required. The entity type of the parameter. Format:
                ``projects/-/locations/-/agents/-/entityTypes/<System Entity Type ID>``
                for system entity types (for example,
                ``projects/-/locations/-/agents/-/entityTypes/sys.date``),
                or
                ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/entityTypes/<Entity Type ID>``
                for developer entity types.
            is_list (bool):
                Indicates whether the parameter represents a
                list of values.
            fill_behavior (google.cloud.dialogflowcx_v3beta1.types.Form.Parameter.FillBehavior):
                Required. Defines fill behavior for the
                parameter.
            default_value (google.protobuf.struct_pb2.Value):
                The default value of an optional parameter.
                If the parameter is required, the default value
                will be ignored.
            redact (bool):
                Indicates whether the parameter content should be redacted
                in log. If redaction is enabled, the parameter content will
                be replaced by parameter name during logging. Note: the
                parameter content is subject to redaction if either
                parameter level redaction or [entity type level
                redaction][google.cloud.dialogflow.cx.v3beta1.EntityType.redact]
                is enabled.
        """

        class FillBehavior(proto.Message):
            r"""Configuration for how the filling of a parameter should be
            handled.

            Attributes:
                initial_prompt_fulfillment (google.cloud.dialogflowcx_v3beta1.types.Fulfillment):
                    Required. The fulfillment to provide the
                    initial prompt that the agent can present to the
                    user in order to fill the parameter.
                reprompt_event_handlers (Sequence[google.cloud.dialogflowcx_v3beta1.types.EventHandler]):
                    The handlers for parameter-level events, used to provide
                    reprompt for the parameter or transition to a different
                    page/flow. The supported events are:

                    -  ``sys.no-match-<N>``, where N can be from 1 to 6
                    -  ``sys.no-match-default``
                    -  ``sys.no-input-<N>``, where N can be from 1 to 6
                    -  ``sys.no-input-default``
                    -  ``sys.invalid-parameter``

                    ``initial_prompt_fulfillment`` provides the first prompt for
                    the parameter.

                    If the user's response does not fill the parameter, a
                    no-match/no-input event will be triggered, and the
                    fulfillment associated with the
                    ``sys.no-match-1``/``sys.no-input-1`` handler (if defined)
                    will be called to provide a prompt. The
                    ``sys.no-match-2``/``sys.no-input-2`` handler (if defined)
                    will respond to the next no-match/no-input event, and so on.

                    A ``sys.no-match-default`` or ``sys.no-input-default``
                    handler will be used to handle all following
                    no-match/no-input events after all numbered
                    no-match/no-input handlers for the parameter are consumed.

                    A ``sys.invalid-parameter`` handler can be defined to handle
                    the case where the parameter values have been
                    ``invalidated`` by webhook. For example, if the user's
                    response fill the parameter, however the parameter was
                    invalidated by webhook, the fulfillment associated with the
                    ``sys.invalid-parameter`` handler (if defined) will be
                    called to provide a prompt.

                    If the event handler for the corresponding event can't be
                    found on the parameter, ``initial_prompt_fulfillment`` will
                    be re-prompted.
            """

            initial_prompt_fulfillment = proto.Field(
                proto.MESSAGE, number=3, message=fulfillment.Fulfillment,
            )
            reprompt_event_handlers = proto.RepeatedField(
                proto.MESSAGE, number=5, message="EventHandler",
            )

        display_name = proto.Field(proto.STRING, number=1,)
        required = proto.Field(proto.BOOL, number=2,)
        entity_type = proto.Field(proto.STRING, number=3,)
        is_list = proto.Field(proto.BOOL, number=4,)
        fill_behavior = proto.Field(
            proto.MESSAGE, number=7, message="Form.Parameter.FillBehavior",
        )
        default_value = proto.Field(proto.MESSAGE, number=9, message=struct_pb2.Value,)
        redact = proto.Field(proto.BOOL, number=11,)

    parameters = proto.RepeatedField(proto.MESSAGE, number=1, message=Parameter,)


class EventHandler(proto.Message):
    r"""An event handler specifies an
    [event][google.cloud.dialogflow.cx.v3beta1.EventHandler.event] that
    can be handled during a session. When the specified event happens,
    the following actions are taken in order:

    -  If there is a
       [``trigger_fulfillment``][google.cloud.dialogflow.cx.v3beta1.EventHandler.trigger_fulfillment]
       associated with the event, it will be called.
    -  If there is a
       [``target_page``][google.cloud.dialogflow.cx.v3beta1.EventHandler.target_page]
       associated with the event, the session will transition into the
       specified page.
    -  If there is a
       [``target_flow``][google.cloud.dialogflow.cx.v3beta1.EventHandler.target_flow]
       associated with the event, the session will transition into the
       specified flow.

    Attributes:
        name (str):
            Output only. The unique identifier of this
            event handler.
        event (str):
            Required. The name of the event to handle.
        trigger_fulfillment (google.cloud.dialogflowcx_v3beta1.types.Fulfillment):
            The fulfillment to call when the event
            occurs. Handling webhook errors with a
            fulfillment enabled with webhook could cause
            infinite loop. It is invalid to specify such
            fulfillment for a handler handling webhooks.
        target_page (str):
            The target page to transition to. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/flows/<Flow ID>/pages/<Page ID>``.
        target_flow (str):
            The target flow to transition to. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/flows/<Flow ID>``.
    """

    name = proto.Field(proto.STRING, number=6,)
    event = proto.Field(proto.STRING, number=4,)
    trigger_fulfillment = proto.Field(
        proto.MESSAGE, number=5, message=fulfillment.Fulfillment,
    )
    target_page = proto.Field(proto.STRING, number=2, oneof="target",)
    target_flow = proto.Field(proto.STRING, number=3, oneof="target",)


class TransitionRoute(proto.Message):
    r"""A transition route specifies a
    [intent][google.cloud.dialogflow.cx.v3beta1.Intent] that can be
    matched and/or a data condition that can be evaluated during a
    session. When a specified transition is matched, the following
    actions are taken in order:

    -  If there is a
       [``trigger_fulfillment``][google.cloud.dialogflow.cx.v3beta1.TransitionRoute.trigger_fulfillment]
       associated with the transition, it will be called.
    -  If there is a
       [``target_page``][google.cloud.dialogflow.cx.v3beta1.TransitionRoute.target_page]
       associated with the transition, the session will transition into
       the specified page.
    -  If there is a
       [``target_flow``][google.cloud.dialogflow.cx.v3beta1.TransitionRoute.target_flow]
       associated with the transition, the session will transition into
       the specified flow.

    Attributes:
        name (str):
            Output only. The unique identifier of this
            transition route.
        intent (str):
            The unique identifier of an
            [Intent][google.cloud.dialogflow.cx.v3beta1.Intent]. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/intents/<Intent ID>``.
            Indicates that the transition can only happen when the given
            intent is matched. At least one of ``intent`` or
            ``condition`` must be specified. When both ``intent`` and
            ``condition`` are specified, the transition can only happen
            when both are fulfilled.
        condition (str):
            The condition to evaluate against [form
            parameters][google.cloud.dialogflow.cx.v3beta1.Form.parameters]
            or [session
            parameters][google.cloud.dialogflow.cx.v3beta1.SessionInfo.parameters].

            See the `conditions
            reference <https://cloud.google.com/dialogflow/cx/docs/reference/condition>`__.
            At least one of ``intent`` or ``condition`` must be
            specified. When both ``intent`` and ``condition`` are
            specified, the transition can only happen when both are
            fulfilled.
        trigger_fulfillment (google.cloud.dialogflowcx_v3beta1.types.Fulfillment):
            The fulfillment to call when the condition is satisfied. At
            least one of ``trigger_fulfillment`` and ``target`` must be
            specified. When both are defined, ``trigger_fulfillment`` is
            executed first.
        target_page (str):
            The target page to transition to. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/flows/<Flow ID>/pages/<Page ID>``.
        target_flow (str):
            The target flow to transition to. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/flows/<Flow ID>``.
    """

    name = proto.Field(proto.STRING, number=6,)
    intent = proto.Field(proto.STRING, number=1,)
    condition = proto.Field(proto.STRING, number=2,)
    trigger_fulfillment = proto.Field(
        proto.MESSAGE, number=3, message=fulfillment.Fulfillment,
    )
    target_page = proto.Field(proto.STRING, number=4, oneof="target",)
    target_flow = proto.Field(proto.STRING, number=5, oneof="target",)


class ListPagesRequest(proto.Message):
    r"""The request message for
    [Pages.ListPages][google.cloud.dialogflow.cx.v3beta1.Pages.ListPages].

    Attributes:
        parent (str):
            Required. The flow to list all pages for. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/flows/<Flow ID>``.
        language_code (str):
            The language to list pages for. The following fields are
            language dependent:

            -  ``Page.entry_fulfillment.messages``
            -  ``Page.entry_fulfillment.conditional_cases``
            -  ``Page.event_handlers.trigger_fulfillment.messages``
            -  ``Page.event_handlers.trigger_fulfillment.conditional_cases``
            -  ``Page.form.parameters.fill_behavior.initial_prompt_fulfillment.messages``
            -

            ``Page.form.parameters.fill_behavior.initial_prompt_fulfillment.conditional_cases``

            -  ``Page.form.parameters.fill_behavior.reprompt_event_handlers.messages``
            -

            ``Page.form.parameters.fill_behavior.reprompt_event_handlers.conditional_cases``

            -  ``Page.transition_routes.trigger_fulfillment.messages``
            -  ``Page.transition_routes.trigger_fulfillment.conditional_cases``

            If not specified, the agent's default language is used.
            `Many
            languages <https://cloud.google.com/dialogflow/cx/docs/reference/language>`__
            are supported. Note: languages must be enabled in the agent
            before they can be used.
        page_size (int):
            The maximum number of items to return in a
            single page. By default 100 and at most 1000.
        page_token (str):
            The next_page_token value returned from a previous list
            request.
    """

    parent = proto.Field(proto.STRING, number=1,)
    language_code = proto.Field(proto.STRING, number=2,)
    page_size = proto.Field(proto.INT32, number=3,)
    page_token = proto.Field(proto.STRING, number=4,)


class ListPagesResponse(proto.Message):
    r"""The response message for
    [Pages.ListPages][google.cloud.dialogflow.cx.v3beta1.Pages.ListPages].

    Attributes:
        pages (Sequence[google.cloud.dialogflowcx_v3beta1.types.Page]):
            The list of pages. There will be a maximum number of items
            returned based on the page_size field in the request.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    pages = proto.RepeatedField(proto.MESSAGE, number=1, message="Page",)
    next_page_token = proto.Field(proto.STRING, number=2,)


class GetPageRequest(proto.Message):
    r"""The request message for
    [Pages.GetPage][google.cloud.dialogflow.cx.v3beta1.Pages.GetPage].

    Attributes:
        name (str):
            Required. The name of the page. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/flows/<Flow ID>/pages/<Page ID>``.
        language_code (str):
            The language to retrieve the page for. The following fields
            are language dependent:

            -  ``Page.entry_fulfillment.messages``
            -  ``Page.entry_fulfillment.conditional_cases``
            -  ``Page.event_handlers.trigger_fulfillment.messages``
            -  ``Page.event_handlers.trigger_fulfillment.conditional_cases``
            -  ``Page.form.parameters.fill_behavior.initial_prompt_fulfillment.messages``
            -

            ``Page.form.parameters.fill_behavior.initial_prompt_fulfillment.conditional_cases``

            -  ``Page.form.parameters.fill_behavior.reprompt_event_handlers.messages``
            -

            ``Page.form.parameters.fill_behavior.reprompt_event_handlers.conditional_cases``

            -  ``Page.transition_routes.trigger_fulfillment.messages``
            -  ``Page.transition_routes.trigger_fulfillment.conditional_cases``

            If not specified, the agent's default language is used.
            `Many
            languages <https://cloud.google.com/dialogflow/cx/docs/reference/language>`__
            are supported. Note: languages must be enabled in the agent
            before they can be used.
    """

    name = proto.Field(proto.STRING, number=1,)
    language_code = proto.Field(proto.STRING, number=2,)


class CreatePageRequest(proto.Message):
    r"""The request message for
    [Pages.CreatePage][google.cloud.dialogflow.cx.v3beta1.Pages.CreatePage].

    Attributes:
        parent (str):
            Required. The flow to create a page for. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/flows/<Flow ID>``.
        page (google.cloud.dialogflowcx_v3beta1.types.Page):
            Required. The page to create.
        language_code (str):
            The language of the following fields in ``page``:

            -  ``Page.entry_fulfillment.messages``
            -  ``Page.entry_fulfillment.conditional_cases``
            -  ``Page.event_handlers.trigger_fulfillment.messages``
            -  ``Page.event_handlers.trigger_fulfillment.conditional_cases``
            -  ``Page.form.parameters.fill_behavior.initial_prompt_fulfillment.messages``
            -

            ``Page.form.parameters.fill_behavior.initial_prompt_fulfillment.conditional_cases``

            -  ``Page.form.parameters.fill_behavior.reprompt_event_handlers.messages``
            -

            ``Page.form.parameters.fill_behavior.reprompt_event_handlers.conditional_cases``

            -  ``Page.transition_routes.trigger_fulfillment.messages``
            -  ``Page.transition_routes.trigger_fulfillment.conditional_cases``

            If not specified, the agent's default language is used.
            `Many
            languages <https://cloud.google.com/dialogflow/cx/docs/reference/language>`__
            are supported. Note: languages must be enabled in the agent
            before they can be used.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page = proto.Field(proto.MESSAGE, number=2, message="Page",)
    language_code = proto.Field(proto.STRING, number=3,)


class UpdatePageRequest(proto.Message):
    r"""The request message for
    [Pages.UpdatePage][google.cloud.dialogflow.cx.v3beta1.Pages.UpdatePage].

    Attributes:
        page (google.cloud.dialogflowcx_v3beta1.types.Page):
            Required. The page to update.
        language_code (str):
            The language of the following fields in ``page``:

            -  ``Page.entry_fulfillment.messages``
            -  ``Page.entry_fulfillment.conditional_cases``
            -  ``Page.event_handlers.trigger_fulfillment.messages``
            -  ``Page.event_handlers.trigger_fulfillment.conditional_cases``
            -  ``Page.form.parameters.fill_behavior.initial_prompt_fulfillment.messages``
            -

            ``Page.form.parameters.fill_behavior.initial_prompt_fulfillment.conditional_cases``

            -  ``Page.form.parameters.fill_behavior.reprompt_event_handlers.messages``
            -

            ``Page.form.parameters.fill_behavior.reprompt_event_handlers.conditional_cases``

            -  ``Page.transition_routes.trigger_fulfillment.messages``
            -  ``Page.transition_routes.trigger_fulfillment.conditional_cases``

            If not specified, the agent's default language is used.
            `Many
            languages <https://cloud.google.com/dialogflow/cx/docs/reference/language>`__
            are supported. Note: languages must be enabled in the agent
            before they can be used.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            The mask to control which fields get updated.
            If the mask is not present, all fields will be
            updated.
    """

    page = proto.Field(proto.MESSAGE, number=1, message="Page",)
    language_code = proto.Field(proto.STRING, number=2,)
    update_mask = proto.Field(
        proto.MESSAGE, number=3, message=field_mask_pb2.FieldMask,
    )


class DeletePageRequest(proto.Message):
    r"""The request message for
    [Pages.DeletePage][google.cloud.dialogflow.cx.v3beta1.Pages.DeletePage].

    Attributes:
        name (str):
            Required. The name of the page to delete. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/Flows/<flow ID>/pages/<Page ID>``.
        force (bool):
            This field has no effect for pages with no incoming
            transitions. For pages with incoming transitions:

            -  If ``force`` is set to false, an error will be returned
               with message indicating the incoming transitions.
            -  If ``force`` is set to true, Dialogflow will remove the
               page, as well as any transitions to the page (i.e.
               [Target page][EventHandler.target_page] in event handlers
               or [Target page][TransitionRoute.target_page] in
               transition routes that point to this page will be
               cleared).
    """

    name = proto.Field(proto.STRING, number=1,)
    force = proto.Field(proto.BOOL, number=2,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.cloud.dialogflowcx_v3.types import test_case
from google.protobuf import field_mask_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.dialogflow.cx.v3",
    manifest={
        "Environment",
        "ListEnvironmentsRequest",
        "ListEnvironmentsResponse",
        "GetEnvironmentRequest",
        "CreateEnvironmentRequest",
        "UpdateEnvironmentRequest",
        "DeleteEnvironmentRequest",
        "LookupEnvironmentHistoryRequest",
        "LookupEnvironmentHistoryResponse",
        "ContinuousTestResult",
        "RunContinuousTestRequest",
        "RunContinuousTestResponse",
        "RunContinuousTestMetadata",
        "ListContinuousTestResultsRequest",
        "ListContinuousTestResultsResponse",
    },
)


class Environment(proto.Message):
    r"""Represents an environment for an agent. You can create
    multiple versions of your agent and publish them to separate
    environments. When you edit an agent, you are editing the draft
    agent. At any point, you can save the draft agent as an agent
    version, which is an immutable snapshot of your agent. When you
    save the draft agent, it is published to the default
    environment. When you create agent versions, you can publish
    them to custom environments. You can create a variety of custom
    environments for testing, development, production, etc.

    Attributes:
        name (str):
            The name of the environment. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/environments/<Environment ID>``.
        display_name (str):
            Required. The human-readable name of the
            environment (unique in an agent). Limit of 64
            characters.
        description (str):
            The human-readable description of the
            environment. The maximum length is 500
            characters. If exceeded, the request is
            rejected.
        version_configs (Sequence[google.cloud.dialogflowcx_v3.types.Environment.VersionConfig]):
            Required. A list of configurations for flow versions. You
            should include version configs for all flows that are
            reachable from [``Start Flow``][Agent.start_flow] in the
            agent. Otherwise, an error will be returned.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Update time of this environment.
    """

    class VersionConfig(proto.Message):
        r"""Configuration for the version.
        Attributes:
            version (str):
                Required. Format: projects/<Project
                ID>/locations/<Location ID>/agents/<Agent
                ID>/flows/<Flow ID>/versions/<Version ID>.
        """

        version = proto.Field(proto.STRING, number=1,)

    name = proto.Field(proto.STRING, number=1,)
    display_name = proto.Field(proto.STRING, number=2,)
    description = proto.Field(proto.STRING, number=3,)
    version_configs = proto.RepeatedField(
        proto.MESSAGE, number=6, message=VersionConfig,
    )
    update_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)


class ListEnvironmentsRequest(proto.Message):
    r"""The request message for
    [Environments.ListEnvironments][google.cloud.dialogflow.cx.v3.Environments.ListEnvironments].

    Attributes:
        parent (str):
            Required. The [Agent][google.cloud.dialogflow.cx.v3.Agent]
            to list all environments for. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>``.
        page_size (int):
            The maximum number of items to return in a
            single page. By default 20 and at most 100.
        page_token (str):
            The next_page_token value returned from a previous list
            request.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListEnvironmentsResponse(proto.Message):
    r"""The response message for
    [Environments.ListEnvironments][google.cloud.dialogflow.cx.v3.Environments.ListEnvironments].

    Attributes:
        environments (Sequence[google.cloud.dialogflowcx_v3.types.Environment]):
            The list of environments. There will be a maximum number of
            items returned based on the page_size field in the request.
            The list may in some cases be empty or contain fewer entries
            than page_size even if this isn't the last page.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    environments = proto.RepeatedField(proto.MESSAGE, number=1, message="Environment",)
    next_page_token = proto.Field(proto.STRING, number=2,)


class GetEnvironmentRequest(proto.Message):
    r"""The request message for
    [Environments.GetEnvironment][google.cloud.dialogflow.cx.v3.Environments.GetEnvironment].

    Attributes:
        name (str):
            Required. The name of the
            [Environment][google.cloud.dialogflow.cx.v3.Environment].
            Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/environments/<Environment ID>``.
    """

    name = proto.Field(proto.STRING, number=1,)


class CreateEnvironmentRequest(proto.Message):
    r"""The request message for
    [Environments.CreateEnvironment][google.cloud.dialogflow.cx.v3.Environments.CreateEnvironment].

    Attributes:
        parent (str):
            Required. The [Agent][google.cloud.dialogflow.cx.v3.Agent]
            to create an
            [Environment][google.cloud.dialogflow.cx.v3.Environment]
            for. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>``.
        environment (google.cloud.dialogflowcx_v3.types.Environment):
            Required. The environment to create.
    """

    parent = proto.Field(proto.STRING, number=1,)
    environment = proto.Field(proto.MESSAGE, number=2, message="Environment",)


class UpdateEnvironmentRequest(proto.Message):
    r"""The request message for
    [Environments.UpdateEnvironment][google.cloud.dialogflow.cx.v3.Environments.UpdateEnvironment].

    Attributes:
        environment (google.cloud.dialogflowcx_v3.types.Environment):
            Required. The environment to update.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The mask to control which fields
            get updated.
    """

    environment = proto.Field(proto.MESSAGE, number=1, message="Environment",)
    update_mask = proto.Field(
        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
    )


class DeleteEnvironmentRequest(proto.Message):
    r"""The request message for
    [Environments.DeleteEnvironment][google.cloud.dialogflow.cx.v3.Environments.DeleteEnvironment].

    Attributes:
        name (str):
            Required. The name of the
            [Environment][google.cloud.dialogflow.cx.v3.Environment] to
            delete. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/environments/<Environment ID>``.
    """

    name = proto.Field(proto.STRING, number=1,)


class LookupEnvironmentHistoryRequest(proto.Message):
    r"""The request message for
    [Environments.LookupEnvironmentHistory][google.cloud.dialogflow.cx.v3.Environments.LookupEnvironmentHistory].

    Attributes:
        name (str):
            Required. Resource name of the environment to look up the
            history for. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/environments/<Environment ID>``.
        page_size (int):
            The maximum number of items to return in a
            single page. By default 100 and at most 1000.
        page_token (str):
            The next_page_token value returned from a previous list
            request.
    """

    name = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class LookupEnvironmentHistoryResponse(proto.Message):
    r"""The response message for
    [Environments.LookupEnvironmentHistory][google.cloud.dialogflow.cx.v3.Environments.LookupEnvironmentHistory].

    Attributes:
        environments (Sequence[google.cloud.dialogflowcx_v3.types.Environment]):
            Represents a list of snapshots for an environment. Time of
            the snapshots is stored in
            [``update_time``][google.cloud.dialogflow.cx.v3.Environment.update_time].
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    environments = proto.RepeatedField(proto.MESSAGE, number=1, message="Environment",)
    next_page_token = proto.Field(proto.STRING, number=2,)


class ContinuousTestResult(proto.Message):
    r"""Represents a result from running a test case in an agent
    environment.

    Attributes:
        name (str):
            The resource name for the continuous test result. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/environments/<Environment ID>/continuousTestResults/<ContinuousTestResult ID>``.
        result (google.cloud.dialogflowcx_v3.types.ContinuousTestResult.AggregatedTestResult):
            The result of this continuous test run, i.e.
            whether all the tests in this continuous test
            run pass or not.
        test_case_results (Sequence[str]):
            A list of individual test case results names
            in this continuous test run.
        run_time (google.protobuf.timestamp_pb2.Timestamp):
            Time when the continuous testing run starts.
    """

    class AggregatedTestResult(proto.Enum):
        r"""The overall result for a continuous test run in an agent
        environment.
        """
        AGGREGATED_TEST_RESULT_UNSPECIFIED = 0
        PASSED = 1
        FAILED = 2

    name = proto.Field(proto.STRING, number=1,)
    result = proto.Field(proto.ENUM, number=2, enum=AggregatedTestResult,)
    test_case_results = proto.RepeatedField(proto.STRING, number=3,)
    run_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)


class RunContinuousTestRequest(proto.Message):
    r"""The request message for
    [Environments.RunContinuousTest][google.cloud.dialogflow.cx.v3.Environments.RunContinuousTest].

    Attributes:
        environment (str):
            Required. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/environments/<Environment ID>``.
    """

    environment = proto.Field(proto.STRING, number=1,)


class RunContinuousTestResponse(proto.Message):
    r"""The response message for
    [Environments.RunContinuousTest][google.cloud.dialogflow.cx.v3.Environments.RunContinuousTest].

    Attributes:
        continuous_test_result (google.cloud.dialogflowcx_v3.types.ContinuousTestResult):
            The result for a continuous test run.
    """

    continuous_test_result = proto.Field(
        proto.MESSAGE, number=1, message="ContinuousTestResult",
    )


class RunContinuousTestMetadata(proto.Message):
    r"""Metadata returned for the
    [Environments.RunContinuousTest][google.cloud.dialogflow.cx.v3.Environments.RunContinuousTest]
    long running operation.

    Attributes:
        errors (Sequence[google.cloud.dialogflowcx_v3.types.TestError]):
            The test errors.
    """

    errors = proto.RepeatedField(proto.MESSAGE, number=1, message=test_case.TestError,)


class ListContinuousTestResultsRequest(proto.Message):
    r"""The request message for
    [Environments.ListContinuousTestResults][google.cloud.dialogflow.cx.v3.Environments.ListContinuousTestResults].

    Attributes:
        parent (str):
            Required. The environment to list results for. Format:
            ``projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>/ environments/<Environment ID>``.
        page_size (int):
            The maximum number of items to return in a
            single page. By default 100 and at most 1000.
        page_token (str):
            The next_page_token value returned from a previous list
            request.
    """

    parent = proto.Field(proto.STRING, number=1,)
    page_size = proto.Field(proto.INT32, number=2,)
    page_token = proto.Field(proto.STRING, number=3,)


class ListContinuousTestResultsResponse(proto.Message):
    r"""The response message for [Environments.ListTestCaseResults][].
    Attributes:
        continuous_test_results (Sequence[google.cloud.dialogflowcx_v3.types.ContinuousTestResult]):
            The list of continuous test results.
        next_page_token (str):
            Token to retrieve the next page of results,
            or empty if there are no more results in the
            list.
    """

    @property
    def raw_page(self):
        return self

    continuous_test_results = proto.RepeatedField(
        proto.MESSAGE, number=1, message="ContinuousTestResult",
    )
    next_page_token = proto.Field(proto.STRING, number=2,)


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.dialogflowcx_v3.services.agents.client import AgentsClient
from google.cloud.dialogflowcx_v3.services.agents.async_client import AgentsAsyncClient
from google.cloud.dialogflowcx_v3.services.entity_types.client import EntityTypesClient
from google.cloud.dialogflowcx_v3.services.entity_types.async_client import (
    EntityTypesAsyncClient,
)
from google.cloud.dialogflowcx_v3.services.environments.client import EnvironmentsClient
from google.cloud.dialogflowcx_v3.services.environments.async_client import (
    EnvironmentsAsyncClient,
)
from google.cloud.dialogflowcx_v3.services.experiments.client import ExperimentsClient
from google.cloud.dialogflowcx_v3.services.experiments.async_client import (
    ExperimentsAsyncClient,
)
from google.cloud.dialogflowcx_v3.services.flows.client import FlowsClient
from google.cloud.dialogflowcx_v3.services.flows.async_client import FlowsAsyncClient
from google.cloud.dialogflowcx_v3.services.intents.client import IntentsClient
from google.cloud.dialogflowcx_v3.services.intents.async_client import (
    IntentsAsyncClient,
)
from google.cloud.dialogflowcx_v3.services.pages.client import PagesClient
from google.cloud.dialogflowcx_v3.services.pages.async_client import PagesAsyncClient
from google.cloud.dialogflowcx_v3.services.security_settings_service.client import (
    SecuritySettingsServiceClient,
)
from google.cloud.dialogflowcx_v3.services.security_settings_service.async_client import (
    SecuritySettingsServiceAsyncClient,
)
from google.cloud.dialogflowcx_v3.services.session_entity_types.client import (
    SessionEntityTypesClient,
)
from google.cloud.dialogflowcx_v3.services.session_entity_types.async_client import (
    SessionEntityTypesAsyncClient,
)
from google.cloud.dialogflowcx_v3.services.sessions.client import SessionsClient
from google.cloud.dialogflowcx_v3.services.sessions.async_client import (
    SessionsAsyncClient,
)
from google.cloud.dialogflowcx_v3.services.test_cases.client import TestCasesClient
from google.cloud.dialogflowcx_v3.services.test_cases.async_client import (
    TestCasesAsyncClient,
)
from google.cloud.dialogflowcx_v3.services.transition_route_groups.client import (
    TransitionRouteGroupsClient,
)
from google.cloud.dialogflowcx_v3.services.transition_route_groups.async_client import (
    TransitionRouteGroupsAsyncClient,
)
from google.cloud.dialogflowcx_v3.services.versions.client import VersionsClient
from google.cloud.dialogflowcx_v3.services.versions.async_client import (
    VersionsAsyncClient,
)
from google.cloud.dialogflowcx_v3.services.webhooks.client import WebhooksClient
from google.cloud.dialogflowcx_v3.services.webhooks.async_client import (
    WebhooksAsyncClient,
)

from google.cloud.dialogflowcx_v3.types.agent import Agent
from google.cloud.dialogflowcx_v3.types.agent import AgentValidationResult
from google.cloud.dialogflowcx_v3.types.agent import CreateAgentRequest
from google.cloud.dialogflowcx_v3.types.agent import DeleteAgentRequest
from google.cloud.dialogflowcx_v3.types.agent import ExportAgentRequest
from google.cloud.dialogflowcx_v3.types.agent import ExportAgentResponse
from google.cloud.dialogflowcx_v3.types.agent import GetAgentRequest
from google.cloud.dialogflowcx_v3.types.agent import GetAgentValidationResultRequest
from google.cloud.dialogflowcx_v3.types.agent import ListAgentsRequest
from google.cloud.dialogflowcx_v3.types.agent import ListAgentsResponse
from google.cloud.dialogflowcx_v3.types.agent import RestoreAgentRequest
from google.cloud.dialogflowcx_v3.types.agent import SpeechToTextSettings
from google.cloud.dialogflowcx_v3.types.agent import UpdateAgentRequest
from google.cloud.dialogflowcx_v3.types.agent import ValidateAgentRequest
from google.cloud.dialogflowcx_v3.types.audio_config import InputAudioConfig
from google.cloud.dialogflowcx_v3.types.audio_config import OutputAudioConfig
from google.cloud.dialogflowcx_v3.types.audio_config import SpeechWordInfo
from google.cloud.dialogflowcx_v3.types.audio_config import SynthesizeSpeechConfig
from google.cloud.dialogflowcx_v3.types.audio_config import VoiceSelectionParams
from google.cloud.dialogflowcx_v3.types.audio_config import AudioEncoding
from google.cloud.dialogflowcx_v3.types.audio_config import OutputAudioEncoding
from google.cloud.dialogflowcx_v3.types.audio_config import SpeechModelVariant
from google.cloud.dialogflowcx_v3.types.audio_config import SsmlVoiceGender
from google.cloud.dialogflowcx_v3.types.entity_type import CreateEntityTypeRequest
from google.cloud.dialogflowcx_v3.types.entity_type import DeleteEntityTypeRequest
from google.cloud.dialogflowcx_v3.types.entity_type import EntityType
from google.cloud.dialogflowcx_v3.types.entity_type import GetEntityTypeRequest
from google.cloud.dialogflowcx_v3.types.entity_type import ListEntityTypesRequest
from google.cloud.dialogflowcx_v3.types.entity_type import ListEntityTypesResponse
from google.cloud.dialogflowcx_v3.types.entity_type import UpdateEntityTypeRequest
from google.cloud.dialogflowcx_v3.types.environment import ContinuousTestResult
from google.cloud.dialogflowcx_v3.types.environment import CreateEnvironmentRequest
from google.cloud.dialogflowcx_v3.types.environment import DeleteEnvironmentRequest
from google.cloud.dialogflowcx_v3.types.environment import Environment
from google.cloud.dialogflowcx_v3.types.environment import GetEnvironmentRequest
from google.cloud.dialogflowcx_v3.types.environment import (
    ListContinuousTestResultsRequest,
)
from google.cloud.dialogflowcx_v3.types.environment import (
    ListContinuousTestResultsResponse,
)
from google.cloud.dialogflowcx_v3.types.environment import ListEnvironmentsRequest
from google.cloud.dialogflowcx_v3.types.environment import ListEnvironmentsResponse
from google.cloud.dialogflowcx_v3.types.environment import (
    LookupEnvironmentHistoryRequest,
)
from google.cloud.dialogflowcx_v3.types.environment import (
    LookupEnvironmentHistoryResponse,
)
from google.cloud.dialogflowcx_v3.types.environment import RunContinuousTestMetadata
from google.cloud.dialogflowcx_v3.types.environment import RunContinuousTestRequest
from google.cloud.dialogflowcx_v3.types.environment import RunContinuousTestResponse
from google.cloud.dialogflowcx_v3.types.environment import UpdateEnvironmentRequest
from google.cloud.dialogflowcx_v3.types.experiment import CreateExperimentRequest
from google.cloud.dialogflowcx_v3.types.experiment import DeleteExperimentRequest
from google.cloud.dialogflowcx_v3.types.experiment import Experiment
from google.cloud.dialogflowcx_v3.types.experiment import GetExperimentRequest
from google.cloud.dialogflowcx_v3.types.experiment import ListExperimentsRequest
from google.cloud.dialogflowcx_v3.types.experiment import ListExperimentsResponse
from google.cloud.dialogflowcx_v3.types.experiment import StartExperimentRequest
from google.cloud.dialogflowcx_v3.types.experiment import StopExperimentRequest
from google.cloud.dialogflowcx_v3.types.experiment import UpdateExperimentRequest
from google.cloud.dialogflowcx_v3.types.experiment import VariantsHistory
from google.cloud.dialogflowcx_v3.types.experiment import VersionVariants
from google.cloud.dialogflowcx_v3.types.flow import CreateFlowRequest
from google.cloud.dialogflowcx_v3.types.flow import DeleteFlowRequest
from google.cloud.dialogflowcx_v3.types.flow import ExportFlowRequest
from google.cloud.dialogflowcx_v3.types.flow import ExportFlowResponse
from google.cloud.dialogflowcx_v3.types.flow import Flow
from google.cloud.dialogflowcx_v3.types.flow import FlowValidationResult
from google.cloud.dialogflowcx_v3.types.flow import GetFlowRequest
from google.cloud.dialogflowcx_v3.types.flow import GetFlowValidationResultRequest
from google.cloud.dialogflowcx_v3.types.flow import ImportFlowRequest
from google.cloud.dialogflowcx_v3.types.flow import ImportFlowResponse
from google.cloud.dialogflowcx_v3.types.flow import ListFlowsRequest
from google.cloud.dialogflowcx_v3.types.flow import ListFlowsResponse
from google.cloud.dialogflowcx_v3.types.flow import NluSettings
from google.cloud.dialogflowcx_v3.types.flow import TrainFlowRequest
from google.cloud.dialogflowcx_v3.types.flow import UpdateFlowRequest
from google.cloud.dialogflowcx_v3.types.flow import ValidateFlowRequest
from google.cloud.dialogflowcx_v3.types.fulfillment import Fulfillment
from google.cloud.dialogflowcx_v3.types.intent import CreateIntentRequest
from google.cloud.dialogflowcx_v3.types.intent import DeleteIntentRequest
from google.cloud.dialogflowcx_v3.types.intent import GetIntentRequest
from google.cloud.dialogflowcx_v3.types.intent import Intent
from google.cloud.dialogflowcx_v3.types.intent import ListIntentsRequest
from google.cloud.dialogflowcx_v3.types.intent import ListIntentsResponse
from google.cloud.dialogflowcx_v3.types.intent import UpdateIntentRequest
from google.cloud.dialogflowcx_v3.types.intent import IntentView
from google.cloud.dialogflowcx_v3.types.page import CreatePageRequest
from google.cloud.dialogflowcx_v3.types.page import DeletePageRequest
from google.cloud.dialogflowcx_v3.types.page import EventHandler
from google.cloud.dialogflowcx_v3.types.page import Form
from google.cloud.dialogflowcx_v3.types.page import GetPageRequest
from google.cloud.dialogflowcx_v3.types.page import ListPagesRequest
from google.cloud.dialogflowcx_v3.types.page import ListPagesResponse
from google.cloud.dialogflowcx_v3.types.page import Page
from google.cloud.dialogflowcx_v3.types.page import TransitionRoute
from google.cloud.dialogflowcx_v3.types.page import UpdatePageRequest
from google.cloud.dialogflowcx_v3.types.response_message import ResponseMessage
from google.cloud.dialogflowcx_v3.types.security_settings import (
    CreateSecuritySettingsRequest,
)
from google.cloud.dialogflowcx_v3.types.security_settings import (
    DeleteSecuritySettingsRequest,
)
from google.cloud.dialogflowcx_v3.types.security_settings import (
    GetSecuritySettingsRequest,
)
from google.cloud.dialogflowcx_v3.types.security_settings import (
    ListSecuritySettingsRequest,
)
from google.cloud.dialogflowcx_v3.types.security_settings import (
    ListSecuritySettingsResponse,
)
from google.cloud.dialogflowcx_v3.types.security_settings import SecuritySettings
from google.cloud.dialogflowcx_v3.types.security_settings import (
    UpdateSecuritySettingsRequest,
)
from google.cloud.dialogflowcx_v3.types.session import AudioInput
from google.cloud.dialogflowcx_v3.types.session import DetectIntentRequest
from google.cloud.dialogflowcx_v3.types.session import DetectIntentResponse
from google.cloud.dialogflowcx_v3.types.session import DtmfInput
from google.cloud.dialogflowcx_v3.types.session import EventInput
from google.cloud.dialogflowcx_v3.types.session import FulfillIntentRequest
from google.cloud.dialogflowcx_v3.types.session import FulfillIntentResponse
from google.cloud.dialogflowcx_v3.types.session import IntentInput
from google.cloud.dialogflowcx_v3.types.session import Match
from google.cloud.dialogflowcx_v3.types.session import MatchIntentRequest
from google.cloud.dialogflowcx_v3.types.session import MatchIntentResponse
from google.cloud.dialogflowcx_v3.types.session import QueryInput
from google.cloud.dialogflowcx_v3.types.session import QueryParameters
from google.cloud.dialogflowcx_v3.types.session import QueryResult
from google.cloud.dialogflowcx_v3.types.session import SentimentAnalysisResult
from google.cloud.dialogflowcx_v3.types.session import StreamingDetectIntentRequest
from google.cloud.dialogflowcx_v3.types.session import StreamingDetectIntentResponse
from google.cloud.dialogflowcx_v3.types.session import StreamingRecognitionResult
from google.cloud.dialogflowcx_v3.types.session import TextInput
from google.cloud.dialogflowcx_v3.types.session_entity_type import (
    CreateSessionEntityTypeRequest,
)
from google.cloud.dialogflowcx_v3.types.session_entity_type import (
    DeleteSessionEntityTypeRequest,
)
from google.cloud.dialogflowcx_v3.types.session_entity_type import (
    GetSessionEntityTypeRequest,
)
from google.cloud.dialogflowcx_v3.types.session_entity_type import (
    ListSessionEntityTypesRequest,
)
from google.cloud.dialogflowcx_v3.types.session_entity_type import (
    ListSessionEntityTypesResponse,
)
from google.cloud.dialogflowcx_v3.types.session_entity_type import SessionEntityType
from google.cloud.dialogflowcx_v3.types.session_entity_type import (
    UpdateSessionEntityTypeRequest,
)
from google.cloud.dialogflowcx_v3.types.test_case import BatchDeleteTestCasesRequest
from google.cloud.dialogflowcx_v3.types.test_case import BatchRunTestCasesMetadata
from google.cloud.dialogflowcx_v3.types.test_case import BatchRunTestCasesRequest
from google.cloud.dialogflowcx_v3.types.test_case import BatchRunTestCasesResponse
from google.cloud.dialogflowcx_v3.types.test_case import CalculateCoverageRequest
from google.cloud.dialogflowcx_v3.types.test_case import CalculateCoverageResponse
from google.cloud.dialogflowcx_v3.types.test_case import ConversationTurn
from google.cloud.dialogflowcx_v3.types.test_case import CreateTestCaseRequest
from google.cloud.dialogflowcx_v3.types.test_case import ExportTestCasesMetadata
from google.cloud.dialogflowcx_v3.types.test_case import ExportTestCasesRequest
from google.cloud.dialogflowcx_v3.types.test_case import ExportTestCasesResponse
from google.cloud.dialogflowcx_v3.types.test_case import GetTestCaseRequest
from google.cloud.dialogflowcx_v3.types.test_case import GetTestCaseResultRequest
from google.cloud.dialogflowcx_v3.types.test_case import ImportTestCasesMetadata
from google.cloud.dialogflowcx_v3.types.test_case import ImportTestCasesRequest
from google.cloud.dialogflowcx_v3.types.test_case import ImportTestCasesResponse
from google.cloud.dialogflowcx_v3.types.test_case import IntentCoverage
from google.cloud.dialogflowcx_v3.types.test_case import ListTestCaseResultsRequest
from google.cloud.dialogflowcx_v3.types.test_case import ListTestCaseResultsResponse
from google.cloud.dialogflowcx_v3.types.test_case import ListTestCasesRequest
from google.cloud.dialogflowcx_v3.types.test_case import ListTestCasesResponse
from google.cloud.dialogflowcx_v3.types.test_case import RunTestCaseMetadata
from google.cloud.dialogflowcx_v3.types.test_case import RunTestCaseRequest
from google.cloud.dialogflowcx_v3.types.test_case import RunTestCaseResponse
from google.cloud.dialogflowcx_v3.types.test_case import TestCase
from google.cloud.dialogflowcx_v3.types.test_case import TestCaseError
from google.cloud.dialogflowcx_v3.types.test_case import TestCaseResult
from google.cloud.dialogflowcx_v3.types.test_case import TestConfig
from google.cloud.dialogflowcx_v3.types.test_case import TestError
from google.cloud.dialogflowcx_v3.types.test_case import TestRunDifference
from google.cloud.dialogflowcx_v3.types.test_case import TransitionCoverage
from google.cloud.dialogflowcx_v3.types.test_case import TransitionRouteGroupCoverage
from google.cloud.dialogflowcx_v3.types.test_case import UpdateTestCaseRequest
from google.cloud.dialogflowcx_v3.types.test_case import TestResult
from google.cloud.dialogflowcx_v3.types.transition_route_group import (
    CreateTransitionRouteGroupRequest,
)
from google.cloud.dialogflowcx_v3.types.transition_route_group import (
    DeleteTransitionRouteGroupRequest,
)
from google.cloud.dialogflowcx_v3.types.transition_route_group import (
    GetTransitionRouteGroupRequest,
)
from google.cloud.dialogflowcx_v3.types.transition_route_group import (
    ListTransitionRouteGroupsRequest,
)
from google.cloud.dialogflowcx_v3.types.transition_route_group import (
    ListTransitionRouteGroupsResponse,
)
from google.cloud.dialogflowcx_v3.types.transition_route_group import (
    TransitionRouteGroup,
)
from google.cloud.dialogflowcx_v3.types.transition_route_group import (
    UpdateTransitionRouteGroupRequest,
)
from google.cloud.dialogflowcx_v3.types.validation_message import ResourceName
from google.cloud.dialogflowcx_v3.types.validation_message import ValidationMessage
from google.cloud.dialogflowcx_v3.types.version import CreateVersionOperationMetadata
from google.cloud.dialogflowcx_v3.types.version import CreateVersionRequest
from google.cloud.dialogflowcx_v3.types.version import DeleteVersionRequest
from google.cloud.dialogflowcx_v3.types.version import GetVersionRequest
from google.cloud.dialogflowcx_v3.types.version import ListVersionsRequest
from google.cloud.dialogflowcx_v3.types.version import ListVersionsResponse
from google.cloud.dialogflowcx_v3.types.version import LoadVersionRequest
from google.cloud.dialogflowcx_v3.types.version import UpdateVersionRequest
from google.cloud.dialogflowcx_v3.types.version import Version
from google.cloud.dialogflowcx_v3.types.webhook import CreateWebhookRequest
from google.cloud.dialogflowcx_v3.types.webhook import DeleteWebhookRequest
from google.cloud.dialogflowcx_v3.types.webhook import GetWebhookRequest
from google.cloud.dialogflowcx_v3.types.webhook import ListWebhooksRequest
from google.cloud.dialogflowcx_v3.types.webhook import ListWebhooksResponse
from google.cloud.dialogflowcx_v3.types.webhook import PageInfo
from google.cloud.dialogflowcx_v3.types.webhook import SessionInfo
from google.cloud.dialogflowcx_v3.types.webhook import UpdateWebhookRequest
from google.cloud.dialogflowcx_v3.types.webhook import Webhook
from google.cloud.dialogflowcx_v3.types.webhook import WebhookRequest
from google.cloud.dialogflowcx_v3.types.webhook import WebhookResponse

__all__ = (
    "AgentsClient",
    "AgentsAsyncClient",
    "EntityTypesClient",
    "EntityTypesAsyncClient",
    "EnvironmentsClient",
    "EnvironmentsAsyncClient",
    "ExperimentsClient",
    "ExperimentsAsyncClient",
    "FlowsClient",
    "FlowsAsyncClient",
    "IntentsClient",
    "IntentsAsyncClient",
    "PagesClient",
    "PagesAsyncClient",
    "SecuritySettingsServiceClient",
    "SecuritySettingsServiceAsyncClient",
    "SessionEntityTypesClient",
    "SessionEntityTypesAsyncClient",
    "SessionsClient",
    "SessionsAsyncClient",
    "TestCasesClient",
    "TestCasesAsyncClient",
    "TransitionRouteGroupsClient",
    "TransitionRouteGroupsAsyncClient",
    "VersionsClient",
    "VersionsAsyncClient",
    "WebhooksClient",
    "WebhooksAsyncClient",
    "Agent",
    "AgentValidationResult",
    "CreateAgentRequest",
    "DeleteAgentRequest",
    "ExportAgentRequest",
    "ExportAgentResponse",
    "GetAgentRequest",
    "GetAgentValidationResultRequest",
    "ListAgentsRequest",
    "ListAgentsResponse",
    "RestoreAgentRequest",
    "SpeechToTextSettings",
    "UpdateAgentRequest",
    "ValidateAgentRequest",
    "InputAudioConfig",
    "OutputAudioConfig",
    "SpeechWordInfo",
    "SynthesizeSpeechConfig",
    "VoiceSelectionParams",
    "AudioEncoding",
    "OutputAudioEncoding",
    "SpeechModelVariant",
    "SsmlVoiceGender",
    "CreateEntityTypeRequest",
    "DeleteEntityTypeRequest",
    "EntityType",
    "GetEntityTypeRequest",
    "ListEntityTypesRequest",
    "ListEntityTypesResponse",
    "UpdateEntityTypeRequest",
    "ContinuousTestResult",
    "CreateEnvironmentRequest",
    "DeleteEnvironmentRequest",
    "Environment",
    "GetEnvironmentRequest",
    "ListContinuousTestResultsRequest",
    "ListContinuousTestResultsResponse",
    "ListEnvironmentsRequest",
    "ListEnvironmentsResponse",
    "LookupEnvironmentHistoryRequest",
    "LookupEnvironmentHistoryResponse",
    "RunContinuousTestMetadata",
    "RunContinuousTestRequest",
    "RunContinuousTestResponse",
    "UpdateEnvironmentRequest",
    "CreateExperimentRequest",
    "DeleteExperimentRequest",
    "Experiment",
    "GetExperimentRequest",
    "ListExperimentsRequest",
    "ListExperimentsResponse",
    "StartExperimentRequest",
    "StopExperimentRequest",
    "UpdateExperimentRequest",
    "VariantsHistory",
    "VersionVariants",
    "CreateFlowRequest",
    "DeleteFlowRequest",
    "ExportFlowRequest",
    "ExportFlowResponse",
    "Flow",
    "FlowValidationResult",
    "GetFlowRequest",
    "GetFlowValidationResultRequest",
    "ImportFlowRequest",
    "ImportFlowResponse",
    "ListFlowsRequest",
    "ListFlowsResponse",
    "NluSettings",
    "TrainFlowRequest",
    "UpdateFlowRequest",
    "ValidateFlowRequest",
    "Fulfillment",
    "CreateIntentRequest",
    "DeleteIntentRequest",
    "GetIntentRequest",
    "Intent",
    "ListIntentsRequest",
    "ListIntentsResponse",
    "UpdateIntentRequest",
    "IntentView",
    "CreatePageRequest",
    "DeletePageRequest",
    "EventHandler",
    "Form",
    "GetPageRequest",
    "ListPagesRequest",
    "ListPagesResponse",
    "Page",
    "TransitionRoute",
    "UpdatePageRequest",
    "ResponseMessage",
    "CreateSecuritySettingsRequest",
    "DeleteSecuritySettingsRequest",
    "GetSecuritySettingsRequest",
    "ListSecuritySettingsRequest",
    "ListSecuritySettingsResponse",
    "SecuritySettings",
    "UpdateSecuritySettingsRequest",
    "AudioInput",
    "DetectIntentRequest",
    "DetectIntentResponse",
    "DtmfInput",
    "EventInput",
    "FulfillIntentRequest",
    "FulfillIntentResponse",
    "IntentInput",
    "Match",
    "MatchIntentRequest",
    "MatchIntentResponse",
    "QueryInput",
    "QueryParameters",
    "QueryResult",
    "SentimentAnalysisResult",
    "StreamingDetectIntentRequest",
    "StreamingDetectIntentResponse",
    "StreamingRecognitionResult",
    "TextInput",
    "CreateSessionEntityTypeRequest",
    "DeleteSessionEntityTypeRequest",
    "GetSessionEntityTypeRequest",
    "ListSessionEntityTypesRequest",
    "ListSessionEntityTypesResponse",
    "SessionEntityType",
    "UpdateSessionEntityTypeRequest",
    "BatchDeleteTestCasesRequest",
    "BatchRunTestCasesMetadata",
    "BatchRunTestCasesRequest",
    "BatchRunTestCasesResponse",
    "CalculateCoverageRequest",
    "CalculateCoverageResponse",
    "ConversationTurn",
    "CreateTestCaseRequest",
    "ExportTestCasesMetadata",
    "ExportTestCasesRequest",
    "ExportTestCasesResponse",
    "GetTestCaseRequest",
    "GetTestCaseResultRequest",
    "ImportTestCasesMetadata",
    "ImportTestCasesRequest",
    "ImportTestCasesResponse",
    "IntentCoverage",
    "ListTestCaseResultsRequest",
    "ListTestCaseResultsResponse",
    "ListTestCasesRequest",
    "ListTestCasesResponse",
    "RunTestCaseMetadata",
    "RunTestCaseRequest",
    "RunTestCaseResponse",
    "TestCase",
    "TestCaseError",
    "TestCaseResult",
    "TestConfig",
    "TestError",
    "TestRunDifference",
    "TransitionCoverage",
    "TransitionRouteGroupCoverage",
    "UpdateTestCaseRequest",
    "TestResult",
    "CreateTransitionRouteGroupRequest",
    "DeleteTransitionRouteGroupRequest",
    "GetTransitionRouteGroupRequest",
    "ListTransitionRouteGroupsRequest",
    "ListTransitionRouteGroupsResponse",
    "TransitionRouteGroup",
    "UpdateTransitionRouteGroupRequest",
    "ResourceName",
    "ValidationMessage",
    "CreateVersionOperationMetadata",
    "CreateVersionRequest",
    "DeleteVersionRequest",
    "GetVersionRequest",
    "ListVersionsRequest",
    "ListVersionsResponse",
    "LoadVersionRequest",
    "UpdateVersionRequest",
    "Version",
    "CreateWebhookRequest",
    "DeleteWebhookRequest",
    "GetWebhookRequest",
    "ListWebhooksRequest",
    "ListWebhooksResponse",
    "PageInfo",
    "SessionInfo",
    "UpdateWebhookRequest",
    "Webhook",
    "WebhookRequest",
    "WebhookResponse",
)
